==> causeway-bom-3.2.0-source-release.zip: causeway-bom-3.2.0/viewers/wicket/ui/src/main/java/org/apache/causeway/viewer/wicket/ui/components/attributes/AttributeModelChangeDispatcher.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */
package org.apache.causeway.viewer.wicket.ui.components.attributes;

import org.apache.wicket.ajax.AjaxRequestTarget;

import lombok.NonNull;

public interface AttributeModelChangeDispatcher {

    @NonNull Iterable<AttributeModelChangeListener> getChangeListeners();
    @NonNull AttributePanel getScalarPanel();

    default void notifyUpdate(final AjaxRequestTarget target) {
        for (var listener : getChangeListeners()) {
            listener.onUpdate(target, getScalarPanel());
        }
    }

    default void notifyError(final AjaxRequestTarget target) {
        for (var listener : getChangeListeners()) {
            listener.onError(target, getScalarPanel());
        }
    }

}

==> causeway-bom-3.5.0-source-release.zip: causeway-bom-3.5.0/viewers/wicket/ui/src/main/java/org/apache/causeway/viewer/wicket/ui/components/attributes/AttributeModelChangeDispatcher.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */
package org.apache.causeway.viewer.wicket.ui.components.attributes;

import org.apache.wicket.ajax.AjaxRequestTarget;

import org.jspecify.annotations.NonNull;

public interface AttributeModelChangeDispatcher {

    @NonNull Iterable<AttributeModelChangeListener> changeListeners();
    @NonNull AttributePanel attributePanel();

    default void notifyUpdate(final AjaxRequestTarget target) {
        for (var listener : changeListeners()) {
            listener.onUpdate(target, attributePanel());
        }
    }

    default void notifyError(final AjaxRequestTarget target) {
        for (var listener : changeListeners()) {
            listener.onError(target, attributePanel());
        }
    }

}
